
/* Copyright (c) 2012 by Al Williams

Permission is hereby granted, free of charge, to any person obtaining a copy of this software
and associated documentation files (the "Software"), to deal in the Software without restriction,
including without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense,
and/or sell copies of the Software, and to permit persons to whom the Software is furnished to do so,
subject to the following conditions:

The above copyright notice and this permission notice shall be included in all copies or substantial
portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT
LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

This software is intended to communicate with a GP9 device. Note that the above license covers,
However, this software does not include the firmware that resides inside the GP9. The above license
covers THIS software and not the GP9 firmware, which is not included in this distribution.

More info: http://www.awce.com/gp9.htm
al.williams@awce.com

*/
#ifndef GP3LINUX_H
#define GP3LINUX_H
/**
 * @mainpage GP3LIB
 * This is the prototypical C library for the GP3 I/O board from
 * AWC (see <A HREF=http://www.awce.com/gp3.htm>http://www.awce.com/gp3.htm</A>)
 *
 * On Windows you may prefer to use the ActiveX controls provided for the
 * kit in both control form (for VB, Delphi, VC++, etc. or as an ActiveX
 * DLL (useful for WSH, ASP, etc.). In addition, there are older binary-only
 * standard DLLs that are not generated from this source.
 *
 * The strength of this library is that it has two parts: a portable part,
 * and a platform-specific part. AWC provides platform-specific parts
 * for Linux, Win32, and Cygwin. It should be relatively easy to
 * port the library to other C platforms by simply rewriting the platform-
 * specific part.
 *
 * @author Al Williams alw@al-williams.com
 * @version 1.1
 *
 * Documentation version 1
 * For access to this documentation, access http://www.awce.com/gp3doc.zip

 Note that in this case, I've reused this for the GP9 which explains the naming


 */

/** @file
 * This is the header included by the GP3 library and all programs that use it.
 * @author Al Williams alw@al-williams.com
 * @version 1.1
 * @date 17 Feb 2004
 */




/** @defgroup PlatformSpecific Platform Specific Routines
 * Platform-specific functions
 * You must implement these to port the library to a new platform.
 * @{
 */

/** Open the GP3 serial port.
 *   @param port The name of the port (varies by platform, e.g., COM1, /dev/cua0, etc.)
 *   @return -1 for error
 */
int gp3openport(const char *port);  // returns -1 for error
/** Close the GP3 port.
 */
void gp3closeport();
/** Write a byte to the GP3.
 * This function blocks if the GP3 is not ready.
 * @param byte The byte to write
 * @return 1 for success
 */
int gp3write(int byte);   // returns 1 for success
/** Read a byte from the GP3.
 * This function blocks until a byte is received
 * @return Character or -1 in case of error
 */
unsigned int gp3read(void);  // returns character or -1 for error

#endif // GP3LINUX_H
