
/* Copyright (c) 2012 by Al Williams

Permission is hereby granted, free of charge, to any person obtaining a copy of this software
and associated documentation files (the "Software"), to deal in the Software without restriction,
including without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense,
and/or sell copies of the Software, and to permit persons to whom the Software is furnished to do so,
subject to the following conditions:

The above copyright notice and this permission notice shall be included in all copies or substantial
portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT
LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

This software is intended to communicate with a GP9 device. Note that the above license covers,
However, this software does not include the firmware that resides inside the GP9. The above license
covers THIS software and not the GP9 firmware, which is not included in this distribution.

More info: http://www.awce.com/gp9.htm
al.williams@awce.com

*/

#ifndef MAINWINDOW_H
#define MAINWINDOW_H

#include <QMainWindow>
#include <QCheckBox>
#include <QSlider>
#include <QLCDNumber>
#include <QSignalMapper>
#include "gp9.h"

namespace Ui {
    class MainWindow;
}

class MainWindow : public QMainWindow
{
    Q_OBJECT

public:
    explicit MainWindow(QWidget *parent = 0);
    ~MainWindow();

private slots:
    void on_openBtn_clicked();


    void oe_clicked(int);

    void sel_clicked(int);

    void slide_change(int);


private:
    Ui::MainWindow *ui;
    void timerEvent(QTimerEvent *event);
    gp9 *board;
    int timerid;     // our timer
    // scanning the window heirarchy is clumsy and makes it hard to do layouts
    // so instead we build arrays of the controls for output enable, sliders, etc.
    QList<QCheckBox *> oes;   // OE checkbox
    QList<QCheckBox *> selects;  // slider select checkbox
    QList<QSlider *> sliders;   // sliders
    QList<QLCDNumber *>lcds;   // lcd voltmeters (only 5)
// it would be tedious to have to handle signals from 8 sliders, 8 checkboxes etc.
// so these mappers swallow up the signals and emit a single signal to one slot
// with an ID so we know which one sent the signal
    QSignalMapper oemap;
    QSignalMapper selmap;
    QSignalMapper slidemap;
// turn off or on the main UI
    void uiEnable(bool flag=true);
// strip 8 bits and set (or reset) checkboxes accordingly
    void bitset(int bits,QList<QCheckBox *>box,bool invert=false);
    // we keep a local state of select and oe
    // so we only query the board on open and then assumes it stays
    // in sync with us. This is our local cache of select and oe
    int selmask;
    int oemask;


};

#endif // MAINWINDOW_H
